==> zio-aws-ecs_2.13-5.17.104.8-sources.jar: zio/aws/ecs/model/DeleteServiceRequest.scala <==
package zio.aws.ecs.model
import zio.aws.ecs.model.primitives.BoxedBoolean
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DeleteServiceRequest(
    cluster: Option[String] = None,
    service: String,
    force: Option[BoxedBoolean] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ecs.model.DeleteServiceRequest = {
    import DeleteServiceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ecs.model.DeleteServiceRequest
      .builder()
      .optionallyWith(cluster.map(value => value: java.lang.String))(_.cluster)
      .service(service: java.lang.String)
      .optionallyWith(
        force.map(value => BoxedBoolean.unwrap(value): java.lang.Boolean)
      )(_.force)
      .build()
  }
  def asReadOnly: zio.aws.ecs.model.DeleteServiceRequest.ReadOnly =
    zio.aws.ecs.model.DeleteServiceRequest.wrap(buildAwsValue())
}
object DeleteServiceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ecs.model.DeleteServiceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ecs.model.DeleteServiceRequest =
      zio.aws.ecs.model.DeleteServiceRequest(
        cluster.map(value => value),
        service,
        force.map(value => value)
      )
    def cluster: Option[String]
    def service: String
    def force: Option[BoxedBoolean]
    def getCluster: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("cluster", cluster)
    def getService: ZIO[Any, Nothing, String] = ZIO.succeed(service)
    def getForce: ZIO[Any, AwsError, BoxedBoolean] =
      AwsError.unwrapOptionField("force", force)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ecs.model.DeleteServiceRequest
  ) extends zio.aws.ecs.model.DeleteServiceRequest.ReadOnly {
    override val cluster: Option[String] =
      scala.Option(impl.cluster()).map(value => value: String)
    override val service: String = impl.service(): String
    override val force: Option[BoxedBoolean] = scala
      .Option(impl.force())
      .map(value => zio.aws.ecs.model.primitives.BoxedBoolean(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ecs.model.DeleteServiceRequest
  ): zio.aws.ecs.model.DeleteServiceRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ecs_2.13-5.17.130.6-sources.jar: zio/aws/ecs/model/DeleteServiceRequest.scala <==
package zio.aws.ecs.model
import zio.aws.ecs.model.primitives.BoxedBoolean
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DeleteServiceRequest(
    cluster: Option[String] = None,
    service: String,
    force: Option[BoxedBoolean] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ecs.model.DeleteServiceRequest = {
    import DeleteServiceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ecs.model.DeleteServiceRequest
      .builder()
      .optionallyWith(cluster.map(value => value: java.lang.String))(_.cluster)
      .service(service: java.lang.String)
      .optionallyWith(force.map(value => value: java.lang.Boolean))(_.force)
      .build()
  }
  def asReadOnly: zio.aws.ecs.model.DeleteServiceRequest.ReadOnly =
    zio.aws.ecs.model.DeleteServiceRequest.wrap(buildAwsValue())
}
object DeleteServiceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ecs.model.DeleteServiceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ecs.model.DeleteServiceRequest =
      zio.aws.ecs.model.DeleteServiceRequest(
        cluster.map(value => value),
        service,
        force.map(value => value)
      )
    def cluster: Option[String]
    def service: String
    def force: Option[BoxedBoolean]
    def getCluster: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("cluster", cluster)
    def getService: ZIO[Any, Nothing, String] = ZIO.succeed(service)
    def getForce: ZIO[Any, AwsError, BoxedBoolean] =
      AwsError.unwrapOptionField("force", force)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ecs.model.DeleteServiceRequest
  ) extends zio.aws.ecs.model.DeleteServiceRequest.ReadOnly {
    override val cluster: Option[String] =
      scala.Option(impl.cluster()).map(value => value: String)
    override val service: String = impl.service(): String
    override val force: Option[BoxedBoolean] =
      scala.Option(impl.force()).map(value => value: BoxedBoolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ecs.model.DeleteServiceRequest
  ): zio.aws.ecs.model.DeleteServiceRequest.ReadOnly = new Wrapper(impl)
}
